diff --git a/projects/hip/docs/RuntimeAPI/html/globals_enum.html b/projects/hip/docs/RuntimeAPI/html/globals_enum.html new file mode 100644 index 0000000000..76cd3b9e6f --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/globals_enum.html @@ -0,0 +1,120 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: File Members + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/globals_eval.html b/projects/hip/docs/RuntimeAPI/html/globals_eval.html new file mode 100644 index 0000000000..5e5e2c4e57 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/globals_eval.html @@ -0,0 +1,147 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: File Members + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/globals_type.html b/projects/hip/docs/RuntimeAPI/html/globals_type.html new file mode 100644 index 0000000000..2c2504da8c --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/globals_type.html @@ -0,0 +1,114 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: File Members + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html new file mode 100644 index 0000000000..374a22be9b --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__runtime__api_8h.html @@ -0,0 +1,326 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP.public/include/hcc_detail/hip_runtime_api.h File Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ + +
+
+
+Classes | +Macros | +Typedefs | +Enumerations | +Functions
+
+
hip_runtime_api.h File Reference
+
+
+ +

Contains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h. +More...

+
#include <stdint.h>
+#include <stddef.h>
+#include <hcc_detail/host_defines.h>
+#include <hc.hpp>
+
+

Go to the source code of this file.

+ + + + + + +

+Classes

struct  dim3
 
struct  hipEvent_t
 
+ + + + + + + + + + + + + + + + + + + +

+Macros

#define hipStreamDefault   0x00
 Flags that can be used with hipStreamCreateWithFlags. More...
 
+#define hipStreamNonBlocking   0x01
 Stream does not implicitly synchronize with null stream.
 
#define hipEventDefault   0x0
 Flags that can be used with hipEventCreateWithFlags: More...
 
+#define hipEventBlockingSync   0x1
 Waiting will yield CPU. Power-friendly and usage-friendly but may increase latency.
 
+#define hipEventDisableTiming   0x2
 Disable event's capability to record timing information. May improve performance.
 
#define hipEventInterprocess   0x4
 Event can support IPC. More...
 
+ + + + + + + + + + + +

+Typedefs

typedef enum hipFuncCache hipFuncCache
 
typedef enum hipSharedMemConfig hipSharedMemConfig
 
typedef struct dim3 dim3
 
+typedef struct ihipStream_thipStream_t
 
+typedef struct hipEvent_t hipEvent_t
 
+ + + + + + + +

+Enumerations

enum  hipFuncCache { hipFuncCachePreferNone, +hipFuncCachePreferShared, +hipFuncCachePreferL1, +hipFuncCachePreferEqual + }
 
enum  hipSharedMemConfig { hipSharedMemBankSizeDefault, +hipSharedMemBankSizeFourByte, +hipSharedMemBankSizeEightByte + }
 
enum  hipMemcpyKind {
+  hipMemcpyHostToHost = 0, +hipMemcpyHostToDevice = 1, +hipMemcpyDeviceToHost = 2, +hipMemcpyDeviceToDevice =3, +
+  hipMemcpyDefault = 4 +
+ }
 
+ + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +

+Functions

hipError_t hipDeviceSynchronize (void)
 Blocks until the default device has completed all preceding requested tasks. More...
 
hipError_t hipDeviceReset (void)
 Destroy all resources and reset all state on the default device in the current process. More...
 
hipError_t hipSetDevice (int device)
 Set default device to be used for subsequent hip API calls from this thread. More...
 
hipError_t hipGetDevice (int *device)
 Return the default device id for the calling host thread. More...
 
hipError_t hipGetDeviceCount (int *count)
 Return number of compute-capable devices. More...
 
hipError_t hipDeviceGetAttribute (int *pi, hipDeviceAttribute_t attr, int device)
 Query device attribute. More...
 
hipError_t hipDeviceGetProperties (hipDeviceProp_t *prop, int device)
 Returns device properties. More...
 
hipError_t hipDeviceSetCacheConfig (hipFuncCache cacheConfig)
 Set L1/Shared cache partition. More...
 
hipError_t hipDeviceGetCacheConfig (hipFuncCache *cacheConfig)
 Set Cache configuration for a specific function. More...
 
hipError_t hipFuncSetCacheConfig (hipFuncCache config)
 Set Cache configuration for a specific function. More...
 
hipError_t hipDeviceGetSharedMemConfig (hipSharedMemConfig *pConfig)
 Get Shared memory bank configuration. More...
 
hipError_t hipDeviceSetSharedMemConfig (hipSharedMemConfig config)
 Set Shared memory bank configuration. More...
 
hipError_t hipGetLastError (void)
 Return last error returned by any HIP runtime API call and resets the stored error code to hipSuccess. More...
 
hipError_t hipPeekAtLastError (void)
 Return last error returned by any HIP runtime API call. More...
 
const char * hipGetErrorName (hipError_t hip_error)
 Return name of the specified error code in text form. More...
 
const char * hipGetErrorString (hipError_t hip_error)
 Return handy text string message to explain the error which occurred. More...
 
hipError_t hipStreamCreateWithFlags (hipStream_t *stream, unsigned int flags)
 Create an asynchronous stream. More...
 
hipError_t hipStreamWaitEvent (hipStream_t stream, hipEvent_t event, unsigned int flags)
 Make the specified compute stream wait for an event. More...
 
hipError_t hipStreamSynchronize (hipStream_t stream)
 Wait for all commands in stream to complete. More...
 
hipError_t hipStreamDestroy (hipStream_t stream)
 Destroys the specified stream. More...
 
hipError_t hipStreamGetFlags (hipStream_t stream, unsigned int *flags)
 Return flags associated with this stream. More...
 
hipError_t hipEventCreateWithFlags (hipEvent_t *event, unsigned flags)
 Create an event with the specified flags. More...
 
hipError_t hipEventRecord (hipEvent_t event, hipStream_t stream=NULL)
 Record an event in the specified stream. More...
 
hipError_t hipEventDestroy (hipEvent_t event)
 Destroy the specified event. More...
 
hipError_t hipEventSynchronize (hipEvent_t event)
 : Wait for an event to complete. More...
 
hipError_t hipEventElapsedTime (float *ms, hipEvent_t start, hipEvent_t stop)
 Return the elapsed time between two events. More...
 
hipError_t hipEventQuery (hipEvent_t event)
 Query event status. More...
 
hipError_t hipMalloc (void **ptr, size_t size)
 Allocate memory on the default accelerator. More...
 
hipError_t hipMallocHost (void **ptr, size_t size)
 Allocate pinned host memory. More...
 
hipError_t hipFree (void *ptr)
 Free memory allocated by the hcc hip memory allocation API. This API performs an implicit hipDeviceSynchronize() call. More...
 
hipError_t hipFreeHost (void *ptr)
 Free memory allocated by the hcc hip host memory allocation API. More...
 
hipError_t hipMemcpy (void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind)
 Copy data from src to dst. More...
 
hipError_t hipMemcpyToSymbol (const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind)
 Copies sizeBytes bytes from the memory area pointed to by src to the memory area pointed to by offset bytes from the start of symbol symbol. More...
 
hipError_t hipMemcpyAsync (void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream=0)
 Copy data from src to dst asynchronously. More...
 
hipError_t hipMemset (void *dst, int value, size_t sizeBytes)
 Copy data from src to dst asynchronously. More...
 
hipError_t hipMemsetAsync (void *dst, int value, size_t sizeBytes, hipStream_t=0)
 Fills the first sizeBytes bytes of the memory area pointed to by dev with the constant byte value value. More...
 
+hipError_t hipMemGetInfo (size_t *free, size_t *total)
 
hipError_t hipDeviceCanAccessPeer (int *canAccessPeer, int device, int peerDevice)
 Determine if a device can access a peer's memory. More...
 
hipError_t hipDeviceDisablePeerAccess (int peerDevice)
 Disables registering memory on peerDevice for direct access from the current device. More...
 
hipError_t hipDeviceEnablePeerAccess (int peerDevice, unsigned int flags)
 Enables registering memory on peerDevice for direct access from the current device. More...
 
hipError_t hipMemcpyPeer (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes)
 Copies memory from one device to memory on another device. More...
 
hipError_t hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream=0)
 Copies memory from one device to memory on another device. More...
 
hipError_t hipDriverGetVersion (int *driverVersion)
 Returns the approximate HIP driver version. More...
 
hipError_t hipHccGetAccelerator (int deviceId, hc::accelerator *acc)
 Return hc::accelerator associated with the specified deviceId. More...
 
hipError_t hipHccGetAcceleratorView (hipStream_t stream, hc::accelerator_view **av)
 Return hc::accelerator_view associated with the specified stream. More...
 
+

Detailed Description

+

Contains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h.

+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html new file mode 100644 index 0000000000..7e73a981b1 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/hcc__detail_2hip__vector__types_8h.html @@ -0,0 +1,452 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP.public/include/hcc_detail/hip_vector_types.h File Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ + +
+
+
+Macros | +Typedefs | +Functions
+
+
hip_vector_types.h File Reference
+
+
+ +

Defines the different newt vector types for HIP runtime. +More...

+
#include <hc_short_vector.hpp>
+
+

Go to the source code of this file.

+ + + + + + + + + + + +

+Macros

+#define ONE_COMPONENT_ACCESS(T, VT)   inline VT make_ ##VT (T x) { VT t; t.x = x; return t; };
 
+
 
+#define TWO_COMPONENT_ACCESS(T, VT)   inline VT make_ ##VT (T x, T y) { VT t; t.x=x; t.y=y; return t; };
 
+#define THREE_COMPONENT_ACCESS(T, VT)   inline VT make_ ##VT (T x, T y, T z) { VT t; t.x=x; t.y=y; t.z=z; return t; };
 
+#define FOUR_COMPONENT_ACCESS(T, VT)   inline VT make_ ##VT (T x, T y, T z, T w) { VT t; t.x=x; t.y=y; t.z=z; t.w=w; return t; };
 
+ + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +

+Typedefs

+typedef hc::short_vector::char1 char1
 
+typedef hc::short_vector::char2 char2
 
+typedef hc::short_vector::char3 char3
 
+typedef hc::short_vector::char4 char4
 
+typedef hc::short_vector::short1 short1
 
+typedef hc::short_vector::short2 short2
 
+typedef hc::short_vector::short3 short3
 
+typedef hc::short_vector::short4 short4
 
+typedef hc::short_vector::int1 int1
 
+typedef hc::short_vector::int2 int2
 
+typedef hc::short_vector::int3 int3
 
+typedef hc::short_vector::int4 int4
 
+typedef hc::short_vector::long1 long1
 
+typedef hc::short_vector::long2 long2
 
+typedef hc::short_vector::long3 long3
 
+typedef hc::short_vector::long4 long4
 
+typedef hc::short_vector::longlong1 longlong1
 
+typedef hc::short_vector::longlong2 longlong2
 
+typedef hc::short_vector::longlong3 longlong3
 
+typedef hc::short_vector::longlong4 longlong4
 
+typedef hc::short_vector::uchar1 uchar1
 
+typedef hc::short_vector::uchar2 uchar2
 
+typedef hc::short_vector::uchar3 uchar3
 
+typedef hc::short_vector::uchar4 uchar4
 
+typedef hc::short_vector::ushort1 ushort1
 
+typedef hc::short_vector::ushort2 ushort2
 
+typedef hc::short_vector::ushort3 ushort3
 
+typedef hc::short_vector::ushort4 ushort4
 
+typedef hc::short_vector::uint1 uint1
 
+typedef hc::short_vector::uint2 uint2
 
+typedef hc::short_vector::uint3 uint3
 
+typedef hc::short_vector::uint4 uint4
 
+typedef hc::short_vector::ulong1 ulong1
 
+typedef hc::short_vector::ulong2 ulong2
 
+typedef hc::short_vector::ulong3 ulong3
 
+typedef hc::short_vector::ulong4 ulong4
 
+typedef
+hc::short_vector::ulonglong1 
ulonglong1
 
+typedef
+hc::short_vector::ulonglong2 
ulonglong2
 
+typedef
+hc::short_vector::ulonglong3 
ulonglong3
 
+typedef
+hc::short_vector::ulonglong4 
ulonglong4
 
+typedef hc::short_vector::float1 float1
 
+typedef hc::short_vector::float2 float2
 
+typedef hc::short_vector::float3 float3
 
+typedef hc::short_vector::float4 float4
 
+typedef hc::short_vector::double1 double1
 
+typedef hc::short_vector::double2 double2
 
+typedef hc::short_vector::double3 double3
 
+typedef hc::short_vector::double4 double4
 
+ + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +

+Functions

ONE_COMPONENT_ACCESS (signed char, char1)
 
TWO_COMPONENT_ACCESS (signed char, char2)
 
THREE_COMPONENT_ACCESS (signed char, char3)
 
FOUR_COMPONENT_ACCESS (signed char, char4)
 
ONE_COMPONENT_ACCESS (short, short1)
 
TWO_COMPONENT_ACCESS (short, short2)
 
THREE_COMPONENT_ACCESS (short, short3)
 
FOUR_COMPONENT_ACCESS (short, short4)
 
ONE_COMPONENT_ACCESS (int, int1)
 
TWO_COMPONENT_ACCESS (int, int2)
 
THREE_COMPONENT_ACCESS (int, int3)
 
FOUR_COMPONENT_ACCESS (int, int4)
 
ONE_COMPONENT_ACCESS (long int, long1)
 
TWO_COMPONENT_ACCESS (long int, long2)
 
THREE_COMPONENT_ACCESS (long int, long3)
 
FOUR_COMPONENT_ACCESS (long int, long4)
 
ONE_COMPONENT_ACCESS (long long int, ulong1)
 
TWO_COMPONENT_ACCESS (long long int, ulong2)
 
THREE_COMPONENT_ACCESS (long long int, ulong3)
 
FOUR_COMPONENT_ACCESS (long long int, ulong4)
 
ONE_COMPONENT_ACCESS (long long int, longlong1)
 
TWO_COMPONENT_ACCESS (long long int, longlong2)
 
THREE_COMPONENT_ACCESS (long long int, longlong3)
 
FOUR_COMPONENT_ACCESS (long long int, longlong4)
 
ONE_COMPONENT_ACCESS (unsigned char, uchar1)
 
TWO_COMPONENT_ACCESS (unsigned char, uchar2)
 
THREE_COMPONENT_ACCESS (unsigned char, uchar3)
 
FOUR_COMPONENT_ACCESS (unsigned char, uchar4)
 
ONE_COMPONENT_ACCESS (unsigned short, ushort1)
 
TWO_COMPONENT_ACCESS (unsigned short, ushort2)
 
THREE_COMPONENT_ACCESS (unsigned short, ushort3)
 
FOUR_COMPONENT_ACCESS (unsigned short, ushort4)
 
ONE_COMPONENT_ACCESS (unsigned int, uint1)
 
TWO_COMPONENT_ACCESS (unsigned int, uint2)
 
THREE_COMPONENT_ACCESS (unsigned int, uint3)
 
FOUR_COMPONENT_ACCESS (unsigned int, uint4)
 
ONE_COMPONENT_ACCESS (unsigned long int, ulong1)
 
TWO_COMPONENT_ACCESS (unsigned long int, ulong2)
 
THREE_COMPONENT_ACCESS (unsigned long int, ulong3)
 
FOUR_COMPONENT_ACCESS (unsigned long int, ulong4)
 
ONE_COMPONENT_ACCESS (unsigned long long int, ulong1)
 
TWO_COMPONENT_ACCESS (unsigned long long int, ulong2)
 
THREE_COMPONENT_ACCESS (unsigned long long int, ulong3)
 
FOUR_COMPONENT_ACCESS (unsigned long long int, ulong4)
 
ONE_COMPONENT_ACCESS (unsigned long long int, ulonglong1)
 
TWO_COMPONENT_ACCESS (unsigned long long int, ulonglong2)
 
THREE_COMPONENT_ACCESS (unsigned long long int, ulonglong3)
 
FOUR_COMPONENT_ACCESS (unsigned long long int, ulonglong4)
 
ONE_COMPONENT_ACCESS (float, float1)
 
TWO_COMPONENT_ACCESS (float, float2)
 
THREE_COMPONENT_ACCESS (float, float3)
 
FOUR_COMPONENT_ACCESS (float, float4)
 
ONE_COMPONENT_ACCESS (double, double1)
 
TWO_COMPONENT_ACCESS (double, double2)
 
THREE_COMPONENT_ACCESS (double, double3)
 
FOUR_COMPONENT_ACCESS (double, double4)
 
+

Detailed Description

+

Defines the different newt vector types for HIP runtime.

+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html b/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html new file mode 100644 index 0000000000..d95b127f85 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/hip__texture_8h.html @@ -0,0 +1,209 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP.public/include/hcc_detail/hip_texture.h File Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ + +
+
+
+Classes | +Macros | +Typedefs | +Enumerations | +Functions
+
+
hip_texture.h File Reference
+
+
+ +

HIP C++ Texture API for hcc compiler. +More...

+
#include <limits.h>
+#include <hip_runtime.h>
+
+

Go to the source code of this file.

+ + + + + + + + +

+Classes

struct  hipChannelFormatDesc
 
struct  textureReference
 
struct  texture< T, texType, hipTextureReadMode >
 
+ + + + + +

+Macros

+#define hipTextureType1D   1
 
+#define tex1Dfetch(_tex, _addr)   (_tex._dataPtr[_addr])
 
+ + + + + + + +

+Typedefs

+typedef struct hipChannelFormatDesc hipChannelFormatDesc
 
+typedef enum hipTextureReadMode hipTextureReadMode
 
+typedef enum hipTextureFilterMode hipTextureFilterMode
 
+ + + + + +

+Enumerations

enum  hipTextureReadMode { hipReadModeElementType + }
 
enum  hipTextureFilterMode { hipFilterModePoint + }
 
+ + + + + + + + + + + + + +

+Functions

+template<class T >
hipChannelFormatDesc hipCreateChannelDesc ()
 
+template<class T , int dim, enum hipTextureReadMode readMode>
hipError_t hipBindTexture (size_t *offset, struct texture< T, dim, readMode > &tex, const void *devPtr, const struct hipChannelFormatDesc *desc, size_t size=UINT_MAX)
 
+template<class T , int dim, enum hipTextureReadMode readMode>
hipError_t hipBindTexture (size_t *offset, struct texture< T, dim, readMode > &tex, const void *devPtr, size_t size=UINT_MAX)
 
+template<class T , int dim, enum hipTextureReadMode readMode>
hipError_t hipUnbindTexture (struct texture< T, dim, readMode > *tex)
 
+

Detailed Description

+

HIP C++ Texture API for hcc compiler.

+

Enumeration Type Documentation

+ +
+
+ + + + +
enum hipTextureFilterMode
+
+ + +
Enumerator
hipFilterModePoint  +

Point filter mode.

+
+ +
+
+ +
+
+ + + + +
enum hipTextureReadMode
+
+ + +
Enumerator
hipReadModeElementType  +

Read texture as specified element type

+
+ +
+
+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html b/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html new file mode 100644 index 0000000000..9d7b976271 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/host__defines_8h.html @@ -0,0 +1,147 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP.public/include/hcc_detail/host_defines.h File Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ + +
+
+
+Macros
+
+
host_defines.h File Reference
+
+
+ +

TODO-doc. +More...

+ +

Go to the source code of this file.

+ + + + + + + + + + + + + + + + +

+Macros

#define __host__   __attribute__((cpu))
 
+#define __device__   __attribute__((hc))
 
+#define __global__   __attribute__((hc_grid_launch))
 
+#define __noinline__   __attribute__((noinline))
 
+#define __forceinline__   __attribute__((always_inline))
 
+#define __shared__   tile_static
 
+#define __constant__   __attribute__((address_space(2)))
 
+

Detailed Description

+

TODO-doc.

+

Macro Definition Documentation

+ +
+
+ + + + +
#define __host__   __attribute__((cpu))
+
+

Function and kernel markers

+ +
+
+
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/search/defines_1.html b/projects/hip/docs/RuntimeAPI/html/search/defines_1.html new file mode 100644 index 0000000000..9e1d9fa116 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/search/defines_1.html @@ -0,0 +1,26 @@ + + + + + + + + + +
+
Loading...
+
+ +
Searching...
+
No Matches
+ +
+ + diff --git a/projects/hip/docs/RuntimeAPI/html/search/defines_1.js b/projects/hip/docs/RuntimeAPI/html/search/defines_1.js new file mode 100644 index 0000000000..c7c61558ca --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/search/defines_1.js @@ -0,0 +1,4 @@ +var searchData= +[ + ['hipthreadidx_5fx',['hipThreadIdx_x',['../hcc__detail_2hip__runtime_8h.html#a48f5f9da77c5fab1fbcf0205bb347d89',1,'hip_runtime.h']]] +]; diff --git a/projects/hip/docs/RuntimeAPI/html/search/defines_2.html b/projects/hip/docs/RuntimeAPI/html/search/defines_2.html new file mode 100644 index 0000000000..6ef4b980d7 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/search/defines_2.html @@ -0,0 +1,26 @@ + + + + + + + + + +
+
Loading...
+
+ +
Searching...
+
No Matches
+ +
+ + diff --git a/projects/hip/docs/RuntimeAPI/html/search/defines_2.js b/projects/hip/docs/RuntimeAPI/html/search/defines_2.js new file mode 100644 index 0000000000..3eaae3688b --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/search/defines_2.js @@ -0,0 +1,4 @@ +var searchData= +[ + ['one_5fcomponent_5faccess',['ONE_COMPONENT_ACCESS',['../hcc__detail_2hip__vector__types_8h.html#add5d9c0f058c5a52c2b9165a66035d0e',1,'hip_vector_types.h']]] +]; diff --git a/projects/hip/docs/RuntimeAPI/html/search/variables_d.html b/projects/hip/docs/RuntimeAPI/html/search/variables_d.html new file mode 100644 index 0000000000..f47799968f --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/search/variables_d.html @@ -0,0 +1,26 @@ + + + + + + + + + +
+
Loading...
+
+ +
Searching...
+
No Matches
+ +
+ + diff --git a/projects/hip/docs/RuntimeAPI/html/search/variables_d.js b/projects/hip/docs/RuntimeAPI/html/search/variables_d.js new file mode 100644 index 0000000000..e8bf38b99c --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/search/variables_d.js @@ -0,0 +1,4 @@ +var searchData= +[ + ['z',['z',['../structdim3.html#a866e38993ecc4e76fd47311236c16b04',1,'dim3']]] +];